1.18.1 — Rucio 1.2 documentation

# 1.18.1

## General

### Enhancements

- Transfers: Don’t send checksum to FTS if verify_checksum is disabled #1522

### Bugs

- Core & Internals: Site attribute check for lan/wan selection needs to be optional #1528
- Core & Internals: Wrong handling of RSE restriction which crashes judge-repairer #1551
- Life time model: Python exception when specifying an ID to list_exceptions() #1561
- Life time model: Cannot update the state of lifetime exceptions with multiple datasets #1569

## Clients

### Enhancements

- Clients: New option for rucio list-rse-usage to list usage per account #1218
- Clients: Possibility to filter collection on empty state #1273
- Clients: Client should force xrdcp for zip content streaming #1559
- Clients: Resolve archives per default in clients #1560
- Clients: rucio list-dids -h should expose the list of available options #509

### Bugs

- Clients: wrong error message in clients #1223
- Clients: Client fails if auth type is x509_proxy and X509_USER_PROXY is not set #1579

## WebUI

### Enhancements

- WebUI: Summary page for used quotas for users #50

### Bugs

- WebUI: Problems with accessing the REST API and the WebUI in the development docker container #1516
- WebUI: Wrong z-index affecting top-bar drop-down menu #1555 <https://github.com/rucio/rucio/issues/1555>`_